@@ -22,6 +22,7 @@
 
 #include "config.h"
 
+#include <adwaita.h>
 #include <sysprof.h>
 
 #include "sysprof-platform.h"
@@ -45,16 +46,15 @@
 
 struct _SysprofProfilerAssistant
 {
-  GtkBin                parent_instance;
+  GtkWidget             parent_instance;
 
   SysprofProcessModel  *process_model;
 
   /* Template Objects */
   GtkSwitch            *allow_throttling;
   GtkButton            *record_button;
-  GtkEntry             *command_line;
+  AdwEntryRow          *command_line;
   GtkSearchEntry       *search_entry;
-  GtkRevealer          *process_revealer;
   GtkListBox           *process_list_box;
   SysprofEnvironEditor *environ_editor;
   GtkFlowBox           *aid_flow_box;
@@ -70,7 +70,7 @@ enum {
 
 static guint signals [N_SIGNALS];
 
-G_DEFINE_TYPE (SysprofProfilerAssistant, sysprof_profiler_assistant, GTK_TYPE_BIN)
+G_DEFINE_TYPE (SysprofProfilerAssistant, sysprof_profiler_assistant, GTK_TYPE_WIDGET)
 
 /**
  * sysprof_profiler_assistant_new:
@@ -111,12 +111,15 @@ create_process_row_cb (gpointer item_,
 }
 
 static void
-sysprof_profiler_assistant_notify_reveal_child_cb (SysprofProfilerAssistant *self,
-                                                   GParamSpec               *pspec,
-                                                   GtkRevealer              *revealer)
+sysprof_profiler_assistant_notify_active_cb (SysprofProfilerAssistant *self,
+                                             GParamSpec               *pspec,
+                                             GtkSwitch                *switch_)
 {
   g_assert (SYSPROF_IS_PROFILER_ASSISTANT (self));
-  g_assert (GTK_IS_REVEALER (revealer));
+  g_assert (GTK_IS_SWITCH (switch_));
+
+  if (gtk_switch_get_active (switch_))
+    return;
 
   if (self->process_model == NULL)
     {
@@ -152,15 +155,15 @@ sysprof_profiler_assistant_command_line_changed_cb (SysprofProfilerAssistant *se
   gint argc;
 
   g_assert (SYSPROF_IS_PROFILER_ASSISTANT (self));
-  g_assert (GTK_IS_ENTRY (entry));
+  g_assert (ADW_IS_ENTRY_ROW (entry));
 
   style_context = gtk_widget_get_style_context (GTK_WIDGET (entry));
-  text = gtk_entry_get_text (entry);
+  text = gtk_editable_get_text (GTK_EDITABLE (entry));
 
   if (text == NULL || text[0] == 0 || g_shell_parse_argv (text, &argc, &argv, NULL))
-    gtk_style_context_remove_class (style_context, GTK_STYLE_CLASS_ERROR);
+    gtk_style_context_remove_class (style_context, "error");
   else
-    gtk_style_context_add_class (style_context, GTK_STYLE_CLASS_ERROR);
+    gtk_style_context_add_class (style_context, "error");
 }
 
 static void
@@ -222,9 +225,10 @@ sysprof_profiler_assistant_record_clicked_cb (SysprofProfilerAssistant *self,
   sysprof_profiler_set_writer (profiler, writer);
 
   /* Add pids to profiler */
-  gtk_container_foreach (GTK_CONTAINER (self->process_list_box),
-                         (GtkCallback) sysprof_profiler_assistant_foreach_cb,
-                         profiler);
+  for (GtkWidget *child = gtk_widget_get_first_child (GTK_WIDGET (self->process_list_box));
+       child;
+       child = gtk_widget_get_next_sibling (child))
+    sysprof_profiler_assistant_foreach_cb (child, profiler);
 
   /* Setup whole system profiling */
   sysprof_profiler_set_whole_system (profiler, gtk_switch_get_active (self->whole_system_switch));
@@ -237,7 +241,7 @@ sysprof_profiler_assistant_record_clicked_cb (SysprofProfilerAssistant *self,
       const gchar *command;
       gint argc;
 
-      command = gtk_entry_get_text (self->command_line);
+      command = gtk_editable_get_text (GTK_EDITABLE (self->command_line));
       g_shell_parse_argv (command, &argc, &argv, NULL);
 
       sysprof_profiler_set_spawn (profiler, TRUE);
@@ -255,22 +259,24 @@ sysprof_profiler_assistant_record_clicked_cb (SysprofProfilerAssistant *self,
   /* Always add the proc source */
   proc_source = sysprof_proc_source_new ();
   sysprof_profiler_add_source (profiler, proc_source);
-#endif
 
-  if (!gtk_switch_get_active (self->allow_throttling))
-    {
-      g_autoptr(SysprofSource) governor = sysprof_governor_source_new ();
-      sysprof_profiler_add_source (profiler, governor);
-    }
+  {
+    g_autoptr(SysprofSource) governor = sysprof_governor_source_new ();
+    sysprof_governor_source_set_disable_governor (SYSPROF_GOVERNOR_SOURCE (governor),
+                                                  !gtk_switch_get_active (self->allow_throttling));
+    sysprof_profiler_add_source (profiler, governor);
+  }
+#endif
 
   /* Always add symbol decoder to save to file immediately */
   symbols_source = sysprof_symbols_source_new ();
   sysprof_profiler_add_source (profiler, symbols_source);
 
   /* Now allow the aids to add their sources */
-  gtk_container_foreach (GTK_CONTAINER (self->aid_flow_box),
-                         (GtkCallback) sysprof_profiler_assistant_foreach_cb,
-                         profiler);
+  for (GtkWidget *child = gtk_widget_get_first_child (GTK_WIDGET (self->aid_flow_box));
+       child;
+       child = gtk_widget_get_next_sibling (child))
+    sysprof_profiler_assistant_foreach_cb (child, profiler);
 
   g_signal_emit (self, signals [START_RECORDING], 0, profiler);
 }
@@ -308,20 +314,20 @@ filter_by_search_text (GObject  *object,
 
 static void
 sysprof_profiler_assistant_search_changed_cb (SysprofProfilerAssistant *self,
-                                              GtkSearchEntry           *search_entry)
+                                              GtkEditable              *search_entry)
 {
   g_autoptr(SysprofModelFilter) filter = NULL;
-  const gchar *text;
+  const char *text;
 
   g_assert (SYSPROF_IS_PROFILER_ASSISTANT (self));
-  g_assert (GTK_IS_SEARCH_ENTRY (search_entry));
+  g_assert (GTK_IS_EDITABLE (search_entry));
 
   if (self->process_model == NULL)
     return;
 
   sysprof_process_model_queue_reload (self->process_model);
 
-  text = gtk_entry_get_text (GTK_ENTRY (search_entry));
+  text = gtk_editable_get_text (GTK_EDITABLE (search_entry));
 
   if (text[0] == 0)
     {
@@ -344,21 +350,26 @@ sysprof_profiler_assistant_search_changed_cb (SysprofProfilerAssistant *self,
 }
 
 static void
-sysprof_profiler_assistant_destroy (GtkWidget *widget)
+sysprof_profiler_assistant_dispose (GObject *object)
 {
-  SysprofProfilerAssistant *self = (SysprofProfilerAssistant *)widget;
+  SysprofProfilerAssistant *self = (SysprofProfilerAssistant *)object;
+  GtkWidget *child;
 
   g_clear_object (&self->process_model);
 
-  GTK_WIDGET_CLASS (sysprof_profiler_assistant_parent_class)->destroy (widget);
+  while ((child = gtk_widget_get_first_child (GTK_WIDGET (self))))
+    gtk_widget_unparent (child);
+
+  G_OBJECT_CLASS (sysprof_profiler_assistant_parent_class)->dispose (object);
 }
 
 static void
 sysprof_profiler_assistant_class_init (SysprofProfilerAssistantClass *klass)
 {
+  GObjectClass *object_class = G_OBJECT_CLASS (klass);
   GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
-  widget_class->destroy = sysprof_profiler_assistant_destroy;
+  object_class->dispose = sysprof_profiler_assistant_dispose;
 
   /**
    * SysprofProfilerAssistant::start-recording:
@@ -376,12 +387,12 @@ sysprof_profiler_assistant_class_init (SysprofProfilerAssistantClass *klass)
                   G_TYPE_NONE, 1, SYSPROF_TYPE_PROFILER);
 
   gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/sysprof/ui/sysprof-profiler-assistant.ui");
+  gtk_widget_class_set_layout_manager_type (widget_class, GTK_TYPE_BIN_LAYOUT);
   gtk_widget_class_bind_template_child (widget_class, SysprofProfilerAssistant, allow_throttling);
   gtk_widget_class_bind_template_child (widget_class, SysprofProfilerAssistant, aid_flow_box);
   gtk_widget_class_bind_template_child (widget_class, SysprofProfilerAssistant, command_line);
   gtk_widget_class_bind_template_child (widget_class, SysprofProfilerAssistant, environ_editor);
   gtk_widget_class_bind_template_child (widget_class, SysprofProfilerAssistant, process_list_box);
-  gtk_widget_class_bind_template_child (widget_class, SysprofProfilerAssistant, process_revealer);
   gtk_widget_class_bind_template_child (widget_class, SysprofProfilerAssistant, record_button);
   gtk_widget_class_bind_template_child (widget_class, SysprofProfilerAssistant, whole_system_switch);
   gtk_widget_class_bind_template_child (widget_class, SysprofProfilerAssistant, launch_switch);
@@ -427,9 +438,9 @@ sysprof_profiler_assistant_init (SysprofProfilerAssistant *self)
                            self,
                            G_CONNECT_SWAPPED);
 
-  g_signal_connect_object (self->process_revealer,
-                           "notify::reveal-child",
-                           G_CALLBACK (sysprof_profiler_assistant_notify_reveal_child_cb),
+  g_signal_connect_object (self->whole_system_switch,
+                           "notify::active",
+                           G_CALLBACK (sysprof_profiler_assistant_notify_active_cb),
                            self,
                            G_CONNECT_SWAPPED);
 
@@ -464,12 +475,12 @@ sysprof_profiler_assistant_set_executable (SysprofProfilerAssistant *self,
 
   if (path == NULL || path[0] == 0)
     {
-      gtk_entry_set_text (GTK_ENTRY (self->command_line), "");
+      gtk_editable_set_text (GTK_EDITABLE (self->command_line), "");
       gtk_switch_set_active (self->launch_switch, FALSE);
     }
   else
     {
-      gtk_entry_set_text (GTK_ENTRY (self->command_line), path);
+      gtk_editable_set_text (GTK_EDITABLE (self->command_line), path);
       gtk_switch_set_active (self->launch_switch, TRUE);
       gtk_widget_grab_focus (GTK_WIDGET (self->command_line));
     }
